@@ -1,4 +1,5 @@
 import itertools
+import os
 import sqlite3
 import sys
 import warnings
@@ -58,11 +59,13 @@ from .base import (
     _T,
     KT,
     VT,
+    PicklingStrategy,
     SqliteCollectionBase,
     T,
     _SqliteCollectionBaseDatabaseDriver,
     create_tempfile_connection,
     is_hashable,
+    tidy_connection,
 )
 from .set import Set as sc_Set
 
@@ -225,6 +228,7 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
         value_serializer: Optional[Callable[[VT], bytes]] = None,
         value_deserializer: Optional[Callable[[bytes], VT]] = None,
         persist: bool = True,
+        pickling_strategy: PicklingStrategy = PicklingStrategy.whole_table,
     ) -> None:
         if (
             isinstance(__data, self.__class__)
@@ -240,6 +244,7 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
                 serializer=key_serializer,
                 deserializer=key_deserializer,
                 persist=persist,
+                pickling_strategy=pickling_strategy,
                 reference_table_name=__data.table_name,
             )
             self._value_serializer = value_serializer
@@ -250,6 +255,7 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
                 table_name=table_name,
                 serializer=key_serializer,
                 deserializer=key_deserializer,
+                pickling_strategy=pickling_strategy,
                 persist=persist,
             )
             self._value_serializer = (
@@ -459,22 +465,33 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
         state = self.__dict__.copy()
         del state["_connection"]
         cur = self.connection.cursor()
-        state["metadata"] = self._driver_class.dump_metadata_record_by_table_name(self.table_name, cur)
-        state["records"] = self._driver_class.dump_serialized_records(self.table_name, cur)
+        if self.pickling_strategy == PicklingStrategy.whole_table:
+            state["metadata"] = self._driver_class.dump_metadata_record_by_table_name(self.table_name, cur)
+            state["records"] = self._driver_class.dump_serialized_records(self.table_name, cur)
+        else:
+            state["db_file_name"] = os.path.relpath(self._driver_class.get_db_filename(cur))
         return state
 
     def __setstate__(self, state: Mapping[str, Any]) -> None:
-        self.__dict__.update(
-            dict(
-                filter(lambda d: d[0] not in ("metadata", "records"), state.items()),
-                _connection=create_tempfile_connection(),
+        if state["_pickling_strategy"] == PicklingStrategy.whole_table:
+            self.__dict__.update(
+                dict(
+                    filter(lambda d: d[0] not in ("metadata", "records"), state.items()),
+                    _connection=create_tempfile_connection(),
+                )
+            )
+            cur = self._connection.cursor()
+            self._driver_class.load_metadata_record(cur, state["metadata"])
+            self._connection.commit()
+            self._driver_class.load_serialized_records(self.table_name, cur, state["records"])
+            self._connection.commit()
+        else:
+            self.__dict__.update(
+                dict(
+                    filter(lambda d: d[0] not in ("db_file_name",), state.items()),
+                    _connection=tidy_connection(state["db_file_name"]),
+                )
             )
-        )
-        cur = self._connection.cursor()
-        self._driver_class.load_metadata_record(cur, state["metadata"])
-        self._connection.commit()
-        self._driver_class.load_serialized_records(self.table_name, cur, state["records"])
-        self._connection.commit()
 
 
 if sys.version_info >= (3, 8):
